@@ -1,23 +1,10 @@
 /*
     This file is part of Akonadi.
-    Copyright (c) 2003 Andreas Gungl <a.gungl@gmx.de>
-    Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
-    Copyright (c) 2010 Leo Franchi <lfranchi@kde.org>
+    SPDX-FileCopyrightText: 2003 Andreas Gungl <a.gungl@gmx.de>
+    SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+    SPDX-FileCopyrightText: 2010 Leo Franchi <lfranchi@kde.org>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "messagestatus.h"
@@ -59,17 +46,17 @@ Akonadi::MessageStatus::MessageStatus()
     mStatus = StatusUnknown;
 }
 
-bool Akonadi::MessageStatus::operator==(const Akonadi::MessageStatus &other) const
+bool Akonadi::MessageStatus::operator==(Akonadi::MessageStatus other) const
 {
     return mStatus == other.mStatus;
 }
 
-bool Akonadi::MessageStatus::operator!=(const Akonadi::MessageStatus &other) const
+bool Akonadi::MessageStatus::operator!=(Akonadi::MessageStatus other) const
 {
     return mStatus != other.mStatus;
 }
 
-bool Akonadi::MessageStatus::operator&(const Akonadi::MessageStatus &other) const
+bool Akonadi::MessageStatus::operator&(Akonadi::MessageStatus other) const
 {
     if (mStatus == StatusUnread) {
         return !(other.mStatus & StatusRead);
@@ -87,7 +74,7 @@ void Akonadi::MessageStatus::clear()
     mStatus = StatusUnknown;
 }
 
-void Akonadi::MessageStatus::set(const Akonadi::MessageStatus &other)
+void Akonadi::MessageStatus::set(Akonadi::MessageStatus other)
 {
     Q_ASSERT(!(other.mStatus & StatusUnread));
 
@@ -148,7 +135,7 @@ void Akonadi::MessageStatus::set(const Akonadi::MessageStatus &other)
     }
 }
 
-void Akonadi::MessageStatus::toggle(const Akonadi::MessageStatus &other)
+void Akonadi::MessageStatus::toggle(Akonadi::MessageStatus other)
 {
     Q_ASSERT(!(other.mStatus & StatusUnread));
 
